==> phpnuke-5.5.tgz: www/phpnuke/html/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","BIG5");
define("_SEARCH","jM");
define("_LOGIN","nJ");
define("_WRITES","g");
define("_POSTEDON","o");
define("_NICKNAME","nJW");
define("_PASSWORD","KX");
define("_WELCOMETO","w");
define("_EDIT","s");
define("_DELETE","R");
define("_POSTEDBY","KX̬");
define("_READS","\Ū");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">^W@</a> ]");
define("_COMMENTS","N");
define("_PASTARTICLES","He峹");
define("_OLDERARTICLES","ª峹");
define("_BY","");
define("_ON","");
define("_LOGOUT","nX");
define("_WAITINGCONT","eݤ");
define("_SUBMISSIONS","뻼");
define("_WREVIEWS","@~׵ݤ");
define("_WLINKS","쵲ݤ");
define("_EPHEMERIDS","{ɤi");
define("_ONEDAY","vW...");
define("_ASREGISTERED","٨SbܡH<a href=\"modules.php?name=Your_Account\">Ыإ߱b</a>CUϥΪ̥iHɨGDD޲zAպAվΨWo׵\C");
define("_MENUFOR","");
define("_NOBIGSTORY","|LjƵo");
define("_BIGSTORY","I\v̰ɡG");
define("_SURVEY","벼");
define("_POLLS","벼@");
define("_PCOMMENTS","סG");
define("_RESULTS","G");
define("_HREADMORE","\ŪԲӤe...");
define("_CURRENTLY","ثe");
define("_GUESTS","ӻM");
define("_MEMBERS","|buW");
define("_YOUARELOGGED","znJ");
define("_YOUHAVE","z");
define("_PRIVATEMSG","ӨpHT");
define("_YOUAREANON","zΦWϥΤ, Ш<a href=\"modules.php?name=Your_Account\">KOU</a>");
define("_NOTE","G");
define("_ADMIN","޲z");
define("_WERECEIVED","@");
define("_PAGESVIEWS","sC_lG");
define("_TOPIC","sDDD");
define("_UDOWNLOADS","U귽");
define("_VOTE","벼");
define("_VOTES","벼");
define("_MVIEWADMIN","dݡGu޲zݨ");
define("_MVIEWUSERS","dݡGuUϥΪ̯ݨ");
define("_MVIEWANON","dݡGuΦWϥΪ̯ݨ");
define("_MVIEWALL","dݡGҦX");
define("_EXPIRELESSHOUR","Gp@p");
define("_EXPIREIN","");
define("_HTTPREFERERS","HTTP ӷ");
define("_UNLIMITED","L");
define("_HOURS","p");
define("_RSSPROBLEM","ثeӺsDDǰD");
define("_SELECTLANGUAGE","ܻy");
define("_SELECTGUILANG","ܻyG");
define("_NONE","L");
define("_BLOCKPROBLEM","<center>oӰ϶oͰDC</center>");
define("_BLOCKPROBLEM2","<center>oӰ϶{bSe.</center>");
define("_MODULENOTACTIVE","藍_, oӼҲըSҰ!");
define("_NOACTIVEMODULES","ҰʼҲ");
define("_FORADMINTESTS","(޲z̴ե)");
define("_BBFORUMS","QװϺ޲z");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%A, %B %d @ %T %Z");
define("_DATESTRING2","%A, %B %d");


/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","BIG5");
define("_SEARCH","jM");
define("_LOGIN","nJ");
define("_WRITES","g");
define("_POSTEDON","o");
define("_NICKNAME","nJW");
define("_PASSWORD","KX");
define("_WELCOMETO","w");
define("_EDIT","s");
define("_DELETE","R");
define("_POSTEDBY","KX̬");
define("_READS","\Ū");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">^W@</a> ]");
define("_COMMENTS","N");
define("_PASTARTICLES","He峹");
define("_OLDERARTICLES","ª峹");
define("_BY","");
define("_ON","");
define("_LOGOUT","nX");
define("_WAITINGCONT","eݤ");
define("_SUBMISSIONS","뻼");
define("_WREVIEWS","@~׵ݤ");
define("_WLINKS","쵲ݤ");
define("_EPHEMERIDS","{ɤi");
define("_ONEDAY","vW...");
define("_ASREGISTERED","٨SbܡH<a href=\"modules.php?name=Your_Account\">Ыإ߱b</a>CUϥΪ̥iHɨGDD޲zAպAվΨWo׵\C");
define("_MENUFOR","");
define("_NOBIGSTORY","|LjƵo");
define("_BIGSTORY","I\v̰ɡG");
define("_SURVEY","벼");
define("_POLLS","벼@");
define("_PCOMMENTS","סG");
define("_RESULTS","G");
define("_HREADMORE","\ŪԲӤe...");
define("_CURRENTLY","ثe");
define("_GUESTS","ӻM");
define("_MEMBERS","|buW");
define("_YOUARELOGGED","znJ");
define("_YOUHAVE","z");
define("_PRIVATEMSG","ӨpHT");
define("_YOUAREANON","zΦWϥΤ, Ш<a href=\"modules.php?name=Your_Account\">KOU</a>");
define("_NOTE","G");
define("_ADMIN","޲z");
define("_WERECEIVED","@");
define("_PAGESVIEWS","sC_lG");
define("_TOPIC","sDDD");
define("_UDOWNLOADS","U귽");
define("_VOTE","벼");
define("_VOTES","벼");
define("_MVIEWADMIN","dݡGu޲zݨ");
define("_MVIEWUSERS","dݡGuUϥΪ̯ݨ");
define("_MVIEWANON","dݡGuΦWϥΪ̯ݨ");
define("_MVIEWALL","dݡGҦX");
define("_EXPIRELESSHOUR","Gp@p");
define("_EXPIREIN","");
define("_HTTPREFERERS","HTTP ӷ");
define("_UNLIMITED","L");
define("_HOURS","p");
define("_RSSPROBLEM","ثeӺsDDǰD");
define("_SELECTLANGUAGE","ܻy");
define("_SELECTGUILANG","ܻyG");
define("_NONE","L");
define("_BLOCKPROBLEM","<center>oӰ϶oͰDC</center>");
define("_BLOCKPROBLEM2","<center>oӰ϶{bSe.</center>");
define("_MODULENOTACTIVE","藍_, oӼҲըSҰ!");
define("_NOACTIVEMODULES","ҰʼҲ");
define("_FORADMINTESTS","(޲z̴ե)");
define("_BBFORUMS","QװϺ޲z");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%A, %B %d @ %T %Z");
define("_DATESTRING2","%A, %B %d");


/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>
